@@ -14,14 +14,16 @@
  * limitations under the License.
  */
 describe('Submit Notebook Button tests', () => {
-  before(() => {
-    cy.openJupyterLab();
+  beforeEach(() => {
+    cy.deleteFile('*.ipynb');
+
+    cy.bootstrapFile('helloworld.ipynb');
+
+    cy.resetJupyterLab();
   });
 
-  after(() => {
-    // go back to file browser and delete file created for testing
-    cy.get('.lm-TabBar-tab[data-id="filebrowser"]').click();
-    cy.deleteFileByName('Untitled.ipynb');
+  afterEach(() => {
+    cy.deleteFile('*.ipynb');
 
     // Delete runtime configuration used for testing
     cy.exec('elyra-metadata remove runtimes --name=test_runtime', {
@@ -29,32 +31,33 @@ describe('Submit Notebook Button tests', () => {
     });
   });
 
-  it('check "Run as Pipeline" button exists', () => {
-    openNewNotebookFile();
-    cy.contains('Run as Pipeline');
+  it('check Submit Notebook button exists', () => {
+    cy.openFile('helloworld.ipynb');
+    cy.findByText(/run as pipeline/i).should('exist');
   });
 
   it('click the "Run as Pipeline" button should display dialog', () => {
-    // Open runtimes sidebar
-    cy.get('.jp-SideBar [title="Runtimes"]').click();
     // Create runtime configuration
     cy.createRuntimeConfig();
+
     // Validate it is now available
-    cy.get('#elyra-metadata span.elyra-expandableContainer-name').contains(
-      'Test Runtime'
-    );
-    // Click Run as Pipeline button
-    cy.contains('Run as Pipeline').click();
-    // Should have warning for unsaved changes
-    cy.get('.jp-mod-accept > .jp-Dialog-buttonLabel')
-      .contains('Save and Submit')
-      .click();
-    // Check for expected dialog title
-    cy.get('.jp-Dialog')
-      .find('div.jp-Dialog-header')
-      .should('have.text', 'Run notebook as pipeline');
+    cy.get('#elyra-metadata\\:runtimes').within(() => {
+      cy.findByText(/test runtime/i).should('exist');
+    });
+
+    cy.findByRole('tab', { name: /file browser/i }).click();
+
+    openNewNotebookFile();
+
+    // Click submit notebook button
+    cy.findByText(/run as pipeline/i).click();
+
+    cy.findByRole('button', { name: /save and submit/i }).click();
+
+    cy.findByText(/run notebook as pipeline/i).should('exist');
+
     // Dismiss  dialog
-    cy.get('button.jp-mod-reject').click();
+    cy.findByRole('button', { name: /cancel/i }).click();
   });
 });
 
@@ -64,6 +67,8 @@ describe('Submit Notebook Button tests', () => {
 
 const openNewNotebookFile = (): void => {
   cy.get(
-    '.jp-LauncherCard[data-category="Notebook"][title="Python 3"]:visible'
-  ).click();
+    '.jp-LauncherCard[data-category="Notebook"][title*="Python 3"]:visible'
+  )
+    .first()
+    .click();
 };
